/**
 * Required External Modules and Interfaces
 */
import express, {Request, Response} from 'express';
import {Guid} from 'guid-typescript';
import logger from '../../middleware/logger';
import {eventsRouter} from './events/events.router';
import {usersRouter} from './users/users.router';

/**
 * Router Definition
 */
export const calendarRouter = express.Router();

calendarRouter.use('/events', eventsRouter);
calendarRouter.use('/users', usersRouter);


calendarRouter.get('/', async (req: Request, res: Response) => {
	try {
		res.status(200).send('Nachklang e.V. Calendar API Endpoint');
	} catch (e: any) {
		let errorGuid = Guid.create().toString();
		logger.error('Error handling a request: ' + e.message, {reference: errorGuid});
		res.status(500).send({
			'status': 'PROCESSING_ERROR',
			'message': 'Internal Server Error. Try again later.',
			'reference': errorGuid
		});
	}
});
